//
// MIT License (MIT)
// -----------------
//
// Copyright (c) 2012 Vicent Josep Brunch i Benlloch
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in the
// Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
// and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//


#define _CRT_SECURE_NO_WARNINGS

#include <stdio.h>
#include <stdlib.h>
#include <locale.h>

#include "header_locale.h"

#include "LocaleManager.h"






LocaleManager g_menuLocaleMngr;
unsigned int g_currentLanguage = 0;




inline void print_option(unsigned int index, const char *option)
{
	printf("%d - %s\n", index, option);
}

inline void print_pad_lines(const char *title)
{
	printf("\n%s\n\n", title);
}

unsigned int ask_option()
{
	printf ( g_menuLocaleMngr.get_string( MENUS_Locale::CHOSE_OPTION ) );
	char option[256];
	scanf("%s", &option);
	
	return atoi(option);
}

char* ask_game_action(const char *msg)
{
	printf (msg);
	static char lastAction[256];
	scanf("%s", &lastAction);

	return lastAction;
}

void change_language_menu()
{
	print_pad_lines( g_menuLocaleMngr.get_string( MENUS_Locale::SELECT_LANGUAGE ) );

	print_option(1, "English (default)");
	print_option(2, "Espaol");
	print_option(3, "Italian");
	print_option(4, "Extra");

	printf("\n");
	unsigned int option = ask_option();
	
	if (option == 0 || option > 4)
	{
		print_pad_lines( g_menuLocaleMngr.get_string( MENUS_Locale::ERROR_INCORRECT_OPT ) );
	}
	else
	{
		const char* tmpPath[] = { "locale/MENUS_ENG.bin", "locale/MENUS_SPA.bin", "locale/MENUS_ITA.bin", "locale/MENUS_EXT.bin" };
		g_currentLanguage = option-1;
		g_menuLocaleMngr.load_language_from_file( tmpPath[g_currentLanguage] );
	}
	
}


void run_new_game()
{

	LocaleManager gameLocaleMngr;
	const char* tmpPath[] = { "locale/GAME_ENG.bin", "locale/GAME_SPA.bin", "locale/GAME_ITA.bin", "locale/GAME_EXT.bin" };
	gameLocaleMngr.load_language_from_file( tmpPath[g_currentLanguage] );

	print_pad_lines("--------------");
	print_pad_lines("");
	print_pad_lines( gameLocaleMngr.get_string( GAME_Locale::FirstRoom ) );
	ask_game_action(">");
	
	print_pad_lines( gameLocaleMngr.get_string( GAME_Locale::TheMonster ) );
	print_pad_lines( gameLocaleMngr.get_string( GAME_Locale::GameOver ) );
	
	gameLocaleMngr.release_memory();
}


int main ()
{
	setlocale( LC_ALL, "Spanish" );
	
	print_pad_lines("LocaleManager test Program");
	
	g_menuLocaleMngr.load_language_from_file("locale/MENUS_ENG.bin");
	g_currentLanguage = 0;
	
	bool bExit = false;
	
	while(!bExit)
	{
		print_pad_lines( g_menuLocaleMngr.get_string( MENUS_Locale::MAIN_MENU ));

		print_option(1, g_menuLocaleMngr.get_string( MENUS_Locale::NEW_GAME ));
		print_option(2, g_menuLocaleMngr.get_string( MENUS_Locale::CONTINUE_GAME ));
		print_option(3, g_menuLocaleMngr.get_string( MENUS_Locale::CHANGE_LANGUAGE ));
		print_option(4, g_menuLocaleMngr.get_string( MENUS_Locale::EXIT_GAME ));

		printf("\n");
		unsigned int option = ask_option();
		switch(option)
		{
		case 1:
			run_new_game();
			break;
		case 2:
			print_pad_lines( g_menuLocaleMngr.get_string( MENUS_Locale::ERROR_NO_SAVEGAME ) );
			break;
		case 3:
			change_language_menu();
			break;
		case 4:
			bExit = true;
			break;
		default:
			print_pad_lines( g_menuLocaleMngr.get_string( MENUS_Locale::ERROR_INCORRECT_OPT ) );
			break;
		}
	}

	
	return 0;
}