//
// MIT License (MIT)
// -----------------
//
// Copyright (c) 2012 Vicent Josep Brunch i Benlloch
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in the
// Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
// and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//



#include "LocaleManager.h"

#include <stdio.h>
#include <stdlib.h>

LocaleManager::LocaleManager()
{
	m_fileStruct = NULL;
	m_ownedMemory = false;
}

LocaleManager::~LocaleManager()
{
	release_memory();
}

void LocaleManager::release_memory()
{
	if (m_fileStruct != NULL && m_ownedMemory)
	{
		free( m_fileStruct );
	}
	
	m_ownedMemory = false;
	m_fileStruct = NULL;
}

bool LocaleManager::load_language_from_mem( void *pMemory )
{
	if (pMemory == NULL)
	{
		return false;
	}
		
	release_memory();
	
	m_fileStruct = (TextFileStruct*)pMemory;
	m_ownedMemory = false;
	
	return true;
}

bool LocaleManager::load_language_from_file( const char* path )
{
	if (path == NULL)
	{
		return false;
	}

	release_memory();
	

	FILE* file = fopen( path, "rb" );
	
	if (file == NULL)
	{
		return false;
	}
		
	fseek( file, 0, SEEK_END );
	size_t fileSize = ftell(file);
	
	void *pMemBlock = malloc( fileSize );
	
	if (pMemBlock == NULL)
	{
		fclose(file);
		return false;
	}
	
	fseek( file, 0, SEEK_SET );
	
	// TODO check the read count with an assert
	fread( pMemBlock, 1, fileSize, file );
	
	fclose(file);
	
	m_fileStruct = (TextFileStruct*)pMemBlock;
	m_ownedMemory = true;
	
	return true;
}

const LocaleChar* LocaleManager::get_string( unsigned int id )
{
	if (m_fileStruct == NULL)
		return NULL;
		
	return m_fileStruct->get_from_index( id );
}
