//
// MIT License (MIT)
// -----------------
//
// Copyright (c) 2012 Vicent Josep Brunch i Benlloch
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in the
// Software without restriction, including without limitation the rights to use, copy,
// modify, merge, publish, distribute, sublicense, and/or sell copies of the Software,
// and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all copies or
// substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, 
// INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
// FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//



#ifndef __LocaleManager_h__
#define __LocaleManager_h__


// We need to define some "compiler specifics" (unsigned char and unsigned int 32 bytes)
#ifndef U8
typedef unsigned char U8;
#endif // U8

#ifndef U32
#ifdef _MSC_VER
typedef unsigned __int32	U32;
#else // !_MSC_VER
typedef unsigned int		U32;
#endif // !_MSC_VER
#endif // U8



/// We use this typedef to support different types of strings (ascii, unicode, ...)
typedef char LocaleChar;





class LocaleManager
{
private:
	struct TextFileStruct
	{
		U32		stringCount;
		
		inline const LocaleChar* get_from_index(unsigned int index)
		{
			if (index >= stringCount)
			{
				return 0;
			}
			
			U8* pThis = (U8*)this;
			U32* offsets = (U32*)this;
			offsets++;
			pThis += (offsets[index]);
			
			return (const LocaleChar*)( pThis );
		}
	};
	
	
	TextFileStruct*		m_fileStruct;
	bool				m_ownedMemory;
	
public:
	LocaleManager(void);
	~LocaleManager(void);
	
	void release_memory();
	
	bool load_language_from_mem(void *pMemory);
	bool load_language_from_file(const char* path);
	
	const LocaleChar* get_string(unsigned int id);
};


#endif // __LocaleManager_h__
